#
# spec file for package elementary-theme
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           elementary-theme
Version:        5.3.0
Release:        1.10
Summary:        The Elementary GTK theme
License:        GPL-3.0-only
Group:          System/GUI/GNOME
URL:            https://elementary.io/
Source:         https://github.com/elementary/stylesheet/archive/%{version}.tar.gz#/stylesheet-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  meson
BuildArch:      noarch

%description
The official elementary GTK theme designed to be smooth, attractive, fast,
and usable.

%package -n     metatheme-elementary-common
Summary:        Common files for the Elementary GTK theme
Group:          System/GUI/GNOME
Suggests:       gtk2-metatheme-elementary
Suggests:       gtk3-metatheme-elementary

%description -n metatheme-elementary-common
The official elementary GTK theme designed to be smooth, attractive, fast,
and usable.

This package provides the files common to the GTK+ themes and the window
manager themes as well as background images.

%package -n     gtk2-metatheme-elementary
Summary:        GTK+ 2 support for the Elementary GTK theme
Group:          System/GUI/GNOME
Requires:       gtk2-engine-murrine
Requires:       metatheme-elementary-common = %{version}
Supplements:    packageand(metatheme-elementary-common:gtk2)

%description -n gtk2-metatheme-elementary
The official elementary GTK theme designed to be smooth, attractive, fast,
and usable.

This package provides the GTK+ 2 support of Elementary.

%package -n     gtk3-metatheme-elementary
Summary:        GTK+ 3 support for the Elementary GTK theme
Group:          System/GUI/GNOME
Requires:       metatheme-elementary-common = %{version}
Supplements:    packageand(metatheme-elementary-common:gtk3)

%description -n gtk3-metatheme-elementary
The official elementary GTK theme designed to be smooth, attractive, fast,
and usable.

This package provides the GTK+ 3 support of Elementary.

%package -n     plank-theme-elementary
Summary:        The Elementary Plank theme
Group:          System/GUI/GNOME
Requires:       plank

%description -n plank-theme-elementary
The official elementary plank theme.

%package -n     plank-metatheme-elementary
Summary:        GTK+ support for the Elementary Plank theme
Group:          System/GUI/GNOME
Requires:       metatheme-elementary-common = %{version}
Requires:       plank-theme-elementary

%description -n plank-metatheme-elementary
This package provides the elementary GTK+ theme for Plank.

%prep
%setup -q -n stylesheet-%{version}

%build
%meson
%meson_build

%install
%meson_install

mkdir -p %{buildroot}%{_datadir}/plank/themes/elementary
mv \
	%{buildroot}%{_datadir}/themes/elementary/plank/dock.theme \
	%{buildroot}%{_datadir}/plank/themes/elementary/dock.theme
ln -s \
	../../../plank/themes/elementary/dock.theme \
    %{buildroot}%{_datadir}/themes/elementary/plank/dock.theme

%fdupes %{buildroot}%{_datadir}/themes/elementary

%files -n metatheme-elementary-common
%license COPYING
%doc AUTHORS CONTRIBUTORS
%dir %{_datadir}/themes/elementary/
%{_datadir}/themes/elementary/index.theme
%{_datadir}/metainfo/io.elementary.stylesheet.appdata.xml

%files -n gtk2-metatheme-elementary
%{_datadir}/themes/elementary/gtk-2.0/

%files -n gtk3-metatheme-elementary
%{_datadir}/themes/elementary/gtk-3.0/

%files -n plank-theme-elementary
%license COPYING
%dir %{_datadir}/plank
%dir %{_datadir}/plank/themes
%dir %{_datadir}/plank/themes/elementary
%dir %{_datadir}/plank/themes/elementary-dark
%{_datadir}/plank/themes/elementary/dock.theme
%{_datadir}/plank/themes/elementary-dark/dock.theme

%files -n plank-metatheme-elementary
%dir %{_datadir}/themes/elementary/plank
%{_datadir}/themes/elementary/plank/dock.theme
%{_datadir}/themes/elementary/plank/dock-dark.theme

%changelog
* Mon Nov  4 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 5.3.0:
  * Dark style: Matching Plank theme (#560)
  * Only apply border to SSD decoration (#557)
  * Fix scrollbar hover in webkit (#555)
  * Fix GTK references in README (#554)
  * Add a style for separator.wide (#551)
  * Use new BadgeColor property to color Strawberry 300 (#546)
  * Delete CODE_OF_CONDUCT.md
  * Delete FUNDING.yml
  * Remove duplicated search-bar style (#542)
  * Remove styles for Files' DiskRenderer (#541)
  * Remove disabled text and icon shadow (#537)
  * Fix color for disabled flat buttons in list rows (#538)
  * Use the same popover shadow everywhere (#539)
  * Explicitly set color inside keycaps (#536)
* Fri Aug  9 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 5.2.5:
  * Use Black 500 from the official palette for the Dark style
    (#510)
  * Remove background color from disabled Gtk.Button in dark
    stylesheet (#408)
  * Adjust Granite.StorageBar when using dark style (#500)
  * Add undershoot to popovers (#522)
  * Style keycaps in menus (#524)
  * Make Entry and SpinButton Progess more subtle (#521)
  * Fix the border color of insensitive suggested button in dark
    mode (#514)
  * Apps.css: support epiphany floating-bar (#520)
* Thu Jul  4 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 5.2.4:
  * Move primary label to granite-widgets (#513)
  * Fix arrow direction in notebook header (#512)
  * Fix the color of insensitive buttons (#509)
  * Create FUNDING.yml
  * namespace npm package name to avoid github introspection
  * fix inline notebook being 1px smaller when only one tab is
    open (#504)
  * Disable transitions on checkitems (#505)
  * Fix popover submenu arrow styles (#503)
  * Increase Radio/CheckButton contrast when using dark style
    (#499)
* Thu May  2 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 5.2.3:
  * Add support for progressbar.osd (#490)
  * Changes dialog label.primary to em font sizing (#491)
  * Style destructive-action buttons in actionbars (#478)
* Mon Mar  4 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 5.2.2:
  * Invert sidebar badge colors (#479)
  * Fix border for sidebar-row in dark style (#473)
  * Naive raised support for headerbar buttons (#466)
  * Don't set border or shadow on dark infobar close buttons
    (#465)
  * Fix linked widgets in RTL (#455)
  * Shade switches with white overlay (#461)
  * Update .seek-bar scale slider style. (#457)
  * More visible focus for dark entries (#456)
  * Release 5.2.1
  * Always use light switch sliders (#449)
  * Add accent support to scales (#443)
  * Fix notebook background (#435)
  * Add styles for link psuedo classes (#438)
* Thu Dec 20 2018 Jan Engelhardt <jengelh@inai.de>
- Write summaries without the use of em dashes.
* Wed Oct 17 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 5.2.0:
  * Increase contrast of warning class in entries (#417)
  * Fix menuitem color from suggested-action buttons (#409)
  * Unblur the icon used to show Infobar Type (#410)
  * Fix darkened backdrop modeswitch (#414)
  * Make close button icon white in error-type Infobars (#407)
  * Fixes the padding on Gtk.FileChooserButton to be the same as
    Gtk.Entry (#406)
  * Add class for accelerator (#402)
  * Also respect accent color in flat titlebars (#404)
  * Also add margin to radiobuttons with images (#403)
  * Don't change text color for disabled suggested action (#397)
  * Special case flat destructive action buttons (#395)
  * Remove overly specific style (#393)
  * Make checkerboard adapt to light or dark (#392)
  * Split out brand files (#388)
  * Add editorconfig (#387)
  * Add Meson build system (#385)
  * Subfolder (#381)
  * Redo style for checks and radios (#384)
  * Add inline tabbar style (#379)
  * Use mix instead of brighten for disabled titlebar button
    color (#374)
  * Split palette into its own file (#378)
  * Remove unused dark spinbutton rules (#373)
  * Fix dark infobar buttons (#372)
  * Set a background on iconview selections (#371)
  * Overshoot (#340)
  * Remove CSS for Desktop settings hotcorner (#367)
  * Remove support for Gtk < 3.22 (#366)
  * Style box inside the infobar revealer (#365)
- Build with meson
* Fri Jun  8 2018 avvissu@yandex.by
- Add plank-metatheme-elementary package
- Spec file cleanup
* Tue Dec 26 2017 avvissu@yandex.by
- Drop gtk3-engine-unico (nothing provides gtk3-engine-unico)
* Wed Oct 18 2017 avvissu@yandex.by
- Update to 5.1.1:
  * Brighter titlebar (#216)
  * Flatter chrome (#198)
  * Replace colors in gtk.css with palette colors (#197)
  * reduce the height of the panel (#208)
  * Update FSF address (#207)
  * fix text color and shadow in titlebar back buttons (#202)
  * Fix size of circular image buttons (#194)
  * Update README.md (#193)
  * Fix text color for disabled combobox (#179)
  * Fix weird background in wireless dialog box (#185)
  * Make insensitive text color pass WCAG AA (#187)
  * Remove misc 3.18 selectors (#178)
  * Make dark selector for popup more specific (#183)
  * Remove redundant dark titlebar style (#180)
  * Brighten dark colors and increase text contrast (#181)
  * Sidebar stack switcher (#177)
  * Clean up some dark stylesheet selectors (#175)
  * fix expander selectors and animate (#170)
  * Fix some selectors in apps.css (#176)
  * Add a style for flat titlebars (#174)
* Wed Aug 16 2017 avvissu@yandex.by
- Compatibility with gtk >= 3.22
- Change the sourceurl to git
* Mon Aug 14 2017 avvissu@yandex.by
- Update to 5.1.0:
  * Add a style for .keycap (#171)
  * Remove duplicate selector (#169)
  * combine check, radio, and switch selectors (#162)
  * increase sidebar text contrast (#167)
  * Removes some more unused selectors targetting 3.18 (#161)
  * Add attention class (#163)
  * fix a couple of image button selectors (#164)
  * make menu and popup class selectors more specific (#165)
  * update switch selectors (#159)
  * Remove deprecated properties (#160)
  * don't set radius in inline-toolbar (#157)
  * fix infobar selectors (#158)
  * Don't use :not for menuitem (#156)
  * Rewrite menuitems and modelbuttons (#153)
  * Resolve major issues in stack sidebar (#149)
  * select indicator, not the whole mark container (#155)
  * Stop scale slider from extending past the scale (#154)
  * Remove old dialog selectors (#150)
  * make modelbutton look like menuitem (#151)
  * Don't apply button styles to menuitem buttons (#152)
  * Fix rounded windows (#148)
  * fix scale slider in seekbar (#147)
  * refine inline-toolbar selectors, fix bugs (#146)
  * Fix the size of primary dialog label (#145)
  * Clean up scales and fix marks (#143)
  * Replace GtkImage with image (#142)
  * rewrite colorchooser (#137)
  * clean up progressbars (#140)
  * clean up combobox selectors (#138)
  * Make pane sep style selector more specific (#141)
* Mon May  1 2017 avvissu@yandex.by
- Update to 5.0.4
* Sun Jan 22 2017 avvissu@yandex.by
- Update to 5.0.3
- Drop elementary-theme-5.0.1_gtk-3.20.patch
* Sun Sep 18 2016 avvissu@yandex.by
- Update to 5.0.1
- Update theme to gtk >= 3.20 (elementary-theme-5.0.1_gtk-3.20.patch)
- Fix: Plank returned to the default theme
- Spec file cleanup
* Sat Feb 27 2016 mailaender@opensuse.org
- add the plank theme
* Sat Feb 27 2016 mailaender@opensuse.org
- update to version 4.0.6
* Mon May 18 2015 mailaender@opensuse.org
- adhere to https://en.opensuse.org/SourceUrls
* Wed May 13 2015 and.november@opensuse.org
- update to version 4.0.2
